@@ -1,3 +1,6 @@
+from {{cookiecutter.package_name}}.architecture.feature import (
+    Feature, FeatureBatch
+)
 from {{cookiecutter.package_name}}.architecture.prediction import (
     Prediction, PredictionBatch
 )
