@@ -27,7 +27,7 @@ def evaluate_metrics():
             lambda output: output['loss']
         ),
         accuracy=ignite.metrics.Average(lambda output: np.mean([
-            prediction.class_name() == example.class_name
+            prediction.class_name == example.class_name
             for prediction, example in zip(
                 output['predictions'], output['examples']
             )
