@@ -1,5 +1,7 @@
 from workflow.ignite import handlers
 from workflow.ignite import decorators
 
-from workflow.ignite.trainer import trainer
 from workflow.ignite.is_float import is_float
+from workflow.ignite.worker_init import worker_init
+from workflow.ignite.trainer import trainer
+from workflow.ignite.evaluator import evaluator
