@@ -1,13 +1,13 @@
 from workflow.torch.get_conv_output_size import get_conv_output_size
 from workflow.torch.get_model_summary import get_model_summary
 from workflow.torch.initialize_weights import initialize_weights
-from workflow.torch.map_dataset import MapDataset
-from workflow.torch.mixup_batch import mixup_batch
-from workflow.torch.model_device import model_device
+from workflow.torch.module_device import module_device
 from workflow.torch.module_compose import ModuleCompose
 from workflow.torch.to_device import to_device
 from workflow.torch.to_shapes import to_shapes
-from workflow.torch.dataset import Dataset
-from workflow.torch.datastream import Datastream
-from workflow.torch.requires_nograd import requires_nograd
+from workflow.torch.module_train import module_train, module_eval
+from workflow.torch.requires_grad import requires_grad, requires_nograd
 from workflow.torch.set_learning_rate import set_learning_rate
+from workflow.torch.set_seeds import set_seeds
+
+# from datastream import Dataset, Datastream
